@@ -161,7 +161,7 @@ module Parser
       #
       # ```
       # (send nil :foo
-      #   (hash
+      #   (kwargs
       #     (pair
       #       (sym :a)
       #       (int 42))
@@ -426,7 +426,7 @@ module Parser
     def regexp_compose(begin_t, parts, end_t, options)
       begin
         static_regexp(parts, options)
-      rescue RegexpError => e
+      rescue RegexpError, Encoding::UndefinedConversionError => e
         diagnostic :error, :invalid_regexp, { :message => e.message },
                    loc(begin_t).join(loc(end_t))
       end
@@ -518,12 +518,46 @@ module Parser
       n(:pair, [ key, value ], pair_map)
     end
 
+    def pair_label(key_t)
+      key_l = loc(key_t)
+      value_l = key_l.adjust(end_pos: -1)
+
+      label = value(key_t)
+      value =
+        if label =~ /\A[[:lower:]]/
+          n(:ident, [ label.to_sym ], Source::Map::Variable.new(value_l))
+        else
+          n(:const, [ nil, label.to_sym ], Source::Map::Constant.new(nil, value_l, value_l))
+        end
+      pair_keyword(key_t, accessible(value))
+    end
+
     def kwsplat(dstar_t, arg)
       n(:kwsplat, [ arg ],
         unary_op_map(dstar_t, arg))
     end
 
     def associate(begin_t, pairs, end_t)
+      key_set = Set.new
+
+      pairs.each do |pair|
+        next unless pair.type.eql?(:pair)
+
+        key, = *pair
+
+        case key.type
+        when :sym, :str, :int, :float
+        when :rational, :complex, :regexp
+          next unless @parser.version >= 31
+        else
+          next
+        end
+
+        unless key_set.add?(key)
+          diagnostic :warning, :duplicate_hash_key, nil, key.loc.expression
+        end
+      end
+
       n(:hash, [ *pairs ],
         collection_map(begin_t, pairs, end_t))
     end
@@ -560,7 +594,13 @@ module Parser
     end
 
     def gvar(token)
-      n(:gvar, [ value(token).to_sym ],
+      gvar_name = value(token)
+
+      if gvar_name.start_with?('$0') && gvar_name.length > 2
+        diagnostic :error, :gvar_name, { :name => gvar_name }, loc(token)
+      end
+
+      n(:gvar, [ gvar_name.to_sym ],
         variable_map(token))
     end
 
@@ -608,19 +648,36 @@ module Parser
       when :ident
         name, = *node
 
-        if @parser.static_env.declared?(name)
-          if name.to_s == parser.current_arg_stack.top
-            diagnostic :error, :circular_argument_reference,
-                       { :var_name => name.to_s }, node.loc.expression
+        if %w[? !].any? { |c| name.to_s.end_with?(c) }
+          diagnostic :error, :invalid_id_to_get,
+                     { :identifier => name.to_s }, node.loc.expression
+        end
+
+        # Numbered parameters are not declared anywhere,
+        # so they take precedence over method calls in numblock contexts
+        if @parser.version >= 27 && @parser.try_declare_numparam(node)
+          return node.updated(:lvar)
+        end
+
+        unless @parser.static_env.declared?(name)
+          if @parser.version == 33 &&
+              name == :it &&
+              @parser.context.in_block &&
+              !@parser.max_numparam_stack.has_ordinary_params?
+            diagnostic :warning, :ambiguous_it_call, nil, node.loc.expression
           end
 
-          node.updated(:lvar)
-        else
-          name, = *node
-          n(:send, [ nil, name ],
+          return n(:send, [ nil, name ],
             var_send_map(node))
         end
 
+        if name.to_s == parser.current_arg_stack.top
+          diagnostic :error, :circular_argument_reference,
+                     { :var_name => name.to_s }, node.loc.expression
+        end
+
+        node.updated(:lvar)
+
       else
         node
       end
@@ -664,7 +721,7 @@ module Parser
         node.updated(:gvasgn)
 
       when :const
-        unless @parser.context.dynamic_const_definition_allowed?
+        if @parser.context.in_def
           diagnostic :error, :dynamic_const, nil, node.loc.expression
         end
 
@@ -683,6 +740,17 @@ module Parser
 
         node.updated(:lvasgn)
 
+      when :match_var
+        name, = *node
+
+        var_name = node.children[0].to_s
+        name_loc = node.loc.expression
+
+        check_assignment_to_numparam(var_name, name_loc)
+        check_reserved_for_numparam(var_name, name_loc)
+
+        node
+
       when :nil, :self, :true, :false,
            :__FILE__, :__LINE__, :__ENCODING__
         diagnostic :error, :invalid_assignment, nil, node.loc.expression
@@ -818,8 +886,14 @@ module Parser
 
     def args(begin_t, args, end_t, check_args=true)
       args = check_duplicate_args(args) if check_args
-      n(:args, args,
-        collection_map(begin_t, args, end_t))
+      validate_no_forward_arg_after_restarg(args)
+
+      map = collection_map(begin_t, args, end_t)
+      if !self.class.emit_forward_arg && args.length == 1 && args[0].type == :forward_arg
+        n(:forward_args, [], map)
+      else
+        n(:args, args, map)
+      end
     end
 
     def numargs(max_numparam)
@@ -906,9 +980,12 @@ module Parser
     end
 
     def blockarg(amper_t, name_t)
-      check_reserved_for_numparam(value(name_t), loc(name_t))
+      if !name_t.nil?
+        check_reserved_for_numparam(value(name_t), loc(name_t))
+      end
 
-      n(:blockarg, [ value(name_t).to_sym ],
+      arg_name = name_t ? value(name_t).to_sym : nil
+      n(:blockarg, [ arg_name ],
         arg_prefix_map(amper_t, name_t))
     end
 
@@ -1008,6 +1085,14 @@ module Parser
       n(:forwarded_args, [], token_map(dots_t))
     end
 
+    def forwarded_restarg(star_t)
+      n(:forwarded_restarg, [], token_map(star_t))
+    end
+
+    def forwarded_kwrestarg(dstar_t)
+      n(:forwarded_kwrestarg, [], token_map(dstar_t))
+    end
+
     def call_method(receiver, dot_t, selector_t,
                     lparen_t=nil, args=[], rparen_t=nil)
       type = call_type_for_dot(dot_t)
@@ -1618,7 +1703,19 @@ module Parser
           cond
         end
 
-      when :and, :or, :irange, :erange
+      when :and, :or
+        lhs, rhs = *cond
+
+        if @parser.version == 18
+          cond
+        else
+          cond.updated(cond.type, [
+            check_condition(lhs),
+            check_condition(rhs)
+          ])
+        end
+
+      when :irange, :erange
         lhs, rhs = *cond
 
         type = case cond.type
@@ -1626,15 +1723,13 @@ module Parser
         when :erange then :eflipflop
         end
 
-        if [:and, :or].include?(cond.type) &&
-               @parser.version == 18
-          cond
-        else
-          cond.updated(type, [
-            check_condition(lhs),
-            check_condition(rhs)
-          ])
-        end
+        lhs_condition = check_condition(lhs) unless lhs.nil?
+        rhs_condition = check_condition(rhs) unless rhs.nil?
+
+        return cond.updated(type, [
+          lhs_condition,
+          rhs_condition
+        ])
 
       when :regexp
         n(:match_current_line, [ cond ], expr_map(cond.loc.expression))
@@ -1683,6 +1778,21 @@ module Parser
       end
     end
 
+    def validate_no_forward_arg_after_restarg(args)
+      restarg = nil
+      forward_arg = nil
+      args.each do |arg|
+        case arg.type
+        when :restarg then restarg = arg
+        when :forward_arg then forward_arg = arg
+        end
+      end
+
+      if !forward_arg.nil? && !restarg.nil?
+        diagnostic :error, :forward_arg_after_restarg, nil, forward_arg.loc.expression, [restarg.loc.expression]
+      end
+    end
+
     def check_assignment_to_numparam(name, loc)
       # MRI < 2.7 treats numbered parameters as regular variables
       # and so it's allowed to perform assignments like `_1 = 42`.
@@ -2158,6 +2268,10 @@ module Parser
 
     def static_regexp_node(node)
       if node.type == :regexp
+        if @parser.version >= 33 && node.children[0..-2].any? { |child| child.type != :str }
+          return nil
+        end
+
         parts, options = node.children[0..-2], node.children[-1]
         static_regexp(parts, options)
       end
