@@ -28,6 +28,10 @@ class TestCurrent < Minitest::Test
       assert_equal Parser::Ruby31, Parser::CurrentRuby
     when /^3\.2\.\d+/
       assert_equal Parser::Ruby32, Parser::CurrentRuby
+    when /^3\.3\.\d+/
+      assert_equal Parser::Ruby33, Parser::CurrentRuby
+    when /^3\.4\.\d+/
+      assert_equal Parser::Ruby34, Parser::CurrentRuby
     else
       flunk "Update test_current for #{RUBY_VERSION}"
     end
